@@ -2,6 +2,7 @@
 #define NSTD_CORE_H_INCLUDED
 #include "core/arch.h"
 #include "core/char_types.h"
+#include "core/core.h"
 #include "core/def.h"
 #include "core/float_types.h"
 #include "core/int_types.h"
@@ -10,5 +11,4 @@
 #include "core/pointer.h"
 #include "core/slice.h"
 #include "core/str.h"
-#include "core/sys.h"
 #endif
